==> nextcloud-25.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/pt_PT.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "Copy to clipboard" : "Copiar para área de transferência",
    "Copied!" : "Copiado!",
    "Not supported!" : "Não suportado!",
    "Press ⌘-C to copy." : "Pressionar ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Pressionar Ctrl-C para copiar.",
    "First run wizard" : "Wizard de arranque inicial",
    "Add your profile information! For example your email is needed to receive notifications." : "Adicione a sua informação de perfil! Por exemplo, o seu email é necessário para receber notificações.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Adicione a sua informação de perfil! Por exemplo, o seu email é necessário para receber notificações e efectuar a reposição da sua palavra-passe.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Adicione informação ao seu perfil! Definir uma image de perfil e um nome completo para facilitar o reconhecimento em todas as funcionalidades.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Adicione informação ao seu perfil! Defina um nome completo para facilitar o reconhecimento em todas as funcionalidades.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Adicione informação ao seu perfil! Defina uma imagem de perfil para facilitar o reconhecimento em todas as funcionalidades.",
    "App recommendation: Nextcloud Calendar" : "Recomendação de aplicação: Calendário Nextcloud",
    "Schedule work & meetings, synced with all your devices." : "Agende trabalho e reuniões, sincronizando com todos os seus dispositivos.",
    "App recommendation: Nextcloud Contacts" : "Recomendação de aplicação: Contactos Nextcloud",
    "Keep your colleagues and friends in one place without leaking their private info." : "Mantenha os seus colegas e amigos no mesmo lugar sem divulgar as suas informações privadas.",
    "App recommendation: Nextcloud Mail" : "Recomendação de aplicação: Correio Nextcloud",
    "App recommendation: Tasks" : "Recomendação de aplicação: Tarefas Nextcloud",
    "App recommendation: Deck" : "Recomendação de aplicação: Deck",
    "Smart media tagging for Nextcloud" : "Etiquetamento inteligente de mídia para o Nextcloud",
    "App recommendation: Group folders" : "Recomendação de aplicação: Pastas de grupo",
    "About" : "Sobre",
    "Get the apps to sync your files" : "Obtenha as aplicações para sincronizar os seus ficheiros",
    "Desktop client" : "Cliente de PC",
    "iOS app" : "Aplicação iOS",
    "Connect your desktop apps to %s" : "Ligue as suas aplicações de PC para %s",
    "Connect your calendar" : "Ligar o seu calendário",
    "Connect your contacts" : "Ligar os seus contactos",
    "Access files via WebDAV" : "Aceder aos ficheiros via WebDAV",
    "Download macOS/iOS configuration profile" : "Transferir perfil de configuração de macOS/iOS",
    "Get help" : "Obter ajuda",
    "Start contributing" : "Começar a contribuir",
    "Become part of the Community" : "Faça parte da comunidade",
    "Get more information" : "Obter mais informação",
    "User manual" : "Manual do utilizador",
    "Admin manual" : "Manual do administrador",
    "Developer manual" : "Manual do programador",
    "the Nextcloud forums" : "os fóruns Nextcloud",
    "A safe home for all your data" : "Um local seguro para todos os seus dados",
    "Server address" : "Endereço do servidor",
    "Copy link" : "Copiar hiperligação",
    "App recommendation: Notes" : "Recomendação de aplicação: Notas",
    "Android app" : "Aplicação Android"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/pt_PT.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Wizard de arranque inicial",
    "Add your profile information! For example your email is needed to receive notifications." : "Adicione a sua informação de perfil! Por exemplo, o seu email é necessário para receber notificações.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Adicione a sua informação de perfil! Por exemplo, o seu email é necessário para receber notificações e efetuar a reposição da sua palavra-passe.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Adicione informação ao seu perfil! Definir uma image de perfil e um nome completo para facilitar o reconhecimento em todas as funcionalidades.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Adicione informação ao seu perfil! Defina um nome completo para facilitar o reconhecimento em todas as funcionalidades.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Adicione informação ao seu perfil! Defina uma imagem de perfil para facilitar o reconhecimento em todas as funcionalidades.",
    "Schedule work & meetings, synced with all your devices." : "Agende trabalho e reuniões, sincronizando com todos os seus dispositivos.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Mantenha os seus colegas e amigos no mesmo lugar sem divulgar as suas informações privadas.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplicação de email simples integrada com Ficheiros, Contactos e Calendário.",
    "App recommendation: Tasks" : "Recomendação de aplicação: Tarefas Nextcloud",
    "App recommendation: Deck" : "Recomendação de aplicação: Deck",
    "Smart media tagging for Nextcloud" : "Etiquetamento inteligente de mídia para o Nextcloud",
    "App recommendation: Group folders" : "Recomendação de aplicação: Pastas de grupo",
    "Connect your calendar" : "Ligar o seu calendário",
    "Connect your contacts" : "Ligar os seus contactos",
    "Access files via WebDAV" : "Aceder aos ficheiros via WebDAV",
    "Download macOS/iOS configuration profile" : "Transferir perfil de configuração de macOS/iOS",
    "Desktop client" : "Cliente de PC",
    "iOS app" : "Aplicação iOS",
    "Download on Apple app store" : "Transferir na loja App Store",
    "Download on Google play store" : "Transferir na loja Google Play",
    "Close" : "Fechar",
    "Download For Windows, Mac OS and Linux." : "Transferir para Windows, Mac OS e Linux.",
    "Privacy" : "Privacidade",
    "Community" : "Comunidade",
    "Share via email" : "Partilhar via correio eletrónico",
    "Get the apps to sync your files" : "Obtenha as aplicações para sincronizar os seus ficheiros",
    "Server address" : "Endereço do servidor",
    "Read more" : "Ler mais",
    "Smarter team sharing with Team folders" : "Partilha de equipa mais inteligente com as Pastas de Equipa."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
